rule win_crypmic_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.crypmic."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.crypmic"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 395818 764a 8b7820 03f9 }
            // n = 4, score = 300
            //   395818               | cmp                 dword ptr [eax + 0x18], ebx
            //   764a                 | jbe                 0x4c
            //   8b7820               | mov                 edi, dword ptr [eax + 0x20]
            //   03f9                 | add                 edi, ecx

        $sequence_1 = { 2bc1 74ec 46 3b75fc 770b 8b55f8 }
            // n = 6, score = 300
            //   2bc1                 | sub                 eax, ecx
            //   74ec                 | je                  0xffffffee
            //   46                   | inc                 esi
            //   3b75fc               | cmp                 esi, dword ptr [ebp - 4]
            //   770b                 | ja                  0xd
            //   8b55f8               | mov                 edx, dword ptr [ebp - 8]

        $sequence_2 = { 8b4de4 894f04 8b4de8 894f08 668b4df0 66894f0c 668b45f2 }
            // n = 7, score = 300
            //   8b4de4               | mov                 ecx, dword ptr [ebp - 0x1c]
            //   894f04               | mov                 dword ptr [edi + 4], ecx
            //   8b4de8               | mov                 ecx, dword ptr [ebp - 0x18]
            //   894f08               | mov                 dword ptr [edi + 8], ecx
            //   668b4df0             | mov                 cx, word ptr [ebp - 0x10]
            //   66894f0c             | mov                 word ptr [edi + 0xc], cx
            //   668b45f2             | mov                 ax, word ptr [ebp - 0xe]

        $sequence_3 = { 33d2 8d642400 8d4001 66890c17 }
            // n = 4, score = 300
            //   33d2                 | xor                 edx, edx
            //   8d642400             | lea                 esp, [esp]
            //   8d4001               | lea                 eax, [eax + 1]
            //   66890c17             | mov                 word ptr [edi + edx], cx

        $sequence_4 = { 50 8b4608 6a08 ff7604 ffd0 }
            // n = 5, score = 300
            //   50                   | push                eax
            //   8b4608               | mov                 eax, dword ptr [esi + 8]
            //   6a08                 | push                8
            //   ff7604               | push                dword ptr [esi + 4]
            //   ffd0                 | call                eax

        $sequence_5 = { 33c0 8bcf 66894302 e8???????? }
            // n = 4, score = 300
            //   33c0                 | xor                 eax, eax
            //   8bcf                 | mov                 ecx, edi
            //   66894302             | mov                 word ptr [ebx + 2], ax
            //   e8????????           |                     

        $sequence_6 = { 43 83c704 3b5818 72bb 5f }
            // n = 5, score = 300
            //   43                   | inc                 ebx
            //   83c704               | add                 edi, 4
            //   3b5818               | cmp                 ebx, dword ptr [eax + 0x18]
            //   72bb                 | jb                  0xffffffbd
            //   5f                   | pop                 edi

        $sequence_7 = { 55 8bec 83ec0c 8b413c 53 8b440878 03c1 }
            // n = 7, score = 300
            //   55                   | push                ebp
            //   8bec                 | mov                 ebp, esp
            //   83ec0c               | sub                 esp, 0xc
            //   8b413c               | mov                 eax, dword ptr [ecx + 0x3c]
            //   53                   | push                ebx
            //   8b440878             | mov                 eax, dword ptr [eax + ecx + 0x78]
            //   03c1                 | add                 eax, ecx

        $sequence_8 = { 5d c20800 8b55fc 8b4224 8d0458 0fb70c08 8b421c }
            // n = 7, score = 300
            //   5d                   | pop                 ebp
            //   c20800               | ret                 8
            //   8b55fc               | mov                 edx, dword ptr [ebp - 4]
            //   8b4224               | mov                 eax, dword ptr [edx + 0x24]
            //   8d0458               | lea                 eax, [eax + ebx*2]
            //   0fb70c08             | movzx               ecx, word ptr [eax + ecx]
            //   8b421c               | mov                 eax, dword ptr [edx + 0x1c]

        $sequence_9 = { 8b440878 03c1 8945fc 395818 }
            // n = 4, score = 300
            //   8b440878             | mov                 eax, dword ptr [eax + ecx + 0x78]
            //   03c1                 | add                 eax, ecx
            //   8945fc               | mov                 dword ptr [ebp - 4], eax
            //   395818               | cmp                 dword ptr [eax + 0x18], ebx

    condition:
        7 of them and filesize < 81920
}